#
# spec file for package paraview
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major_ver 5.8
%define shlib libparaview5_8

%if 0%{?suse_version} <= 1500
%bcond_with    pugixml
%else
%bcond_without pugixml
%endif
# Need unrelased version > 1.4.0 with e.g. gl2psTextOptColorBL
%bcond_with    gl2ps
# Need patched version with HPDF_SHADING
%bcond_with    haru

%define __builder ninja

Name:           paraview
Version:        5.8.0
Release:        lp152.3.5
Summary:        Data analysis and visualization application
License:        BSD-3-Clause
Group:          Productivity/Scientific/Physics
URL:            https://www.paraview.org
Source0:        https://www.paraview.org/files/v%{major_ver}/ParaView-v%{version}.tar.xz
Source1:        %{name}-rpmlintrc
# CAUTION: GettingStarted may or may not be updated with each minor version
Source2:        https://www.paraview.org/files/v%{major_ver}/ParaViewGettingStarted-%{major_ver}.0.pdf
Source3:        https://www.paraview.org/files/v%{major_ver}/ParaViewGuide-%{version}.pdf
# PATCH-FIX-UPSTREAM paraview-desktop-entry-fix.patch badshah400@gmail.com -- Fix desktop menu entry by inserting proper required categories
Patch1:         paraview-desktop-entry-fix.patch
# PATCH-FIX-UPSTREAM fix-3d48a287-support-new-api-cgio_read_data_type.patch -- Add support for new API cgio_read_***data***_type
Patch2:         fix-3d48a287-support-new-api-cgio_read_data_type.patch
# PATCH-FIX-OPENSUSE fix-libharu-missing-m.patch -- missing libraries for linking (gh#libharu/libharu#213)
Patch8:         fix-libharu-missing-m.patch
# PATCH-FIX-OPENSUSE bundled_exodusii_add_missing_libpthread.patch stefan.bruens@rwth-aachen.de -- Add missing libm for linking (updated to upstream patch, see https://gitlab.kitware.com/vtk/vtk/-/merge_requests/6865)
Patch10:        bundled_exodusii_add_missing_libpthread.patch
BuildRequires:  Mesa-devel
BuildRequires:  cgns-devel
BuildRequires:  cmake >= 3.13
BuildRequires:  desktop-file-utils
BuildRequires:  double-conversion-devel
BuildRequires:  doxygen
BuildRequires:  exodusii-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gnuplot
BuildRequires:  graphviz
BuildRequires:  hdf5-devel
BuildRequires:  libboost_graph-devel
BuildRequires:  libboost_headers-devel
%if %{with gl2ps}
BuildRequires:  gl2ps-devel
%endif
%if %{with haru}
BuildRequires:  libharu-devel > 2.3.0
%endif
BuildRequires:  libnetcdf_c++-devel
BuildRequires:  ninja
BuildRequires:  python3-Sphinx
BuildRequires:  python3-Twisted
BuildRequires:  python3-devel
BuildRequires:  python3-matplotlib
BuildRequires:  python3-qt5-devel
BuildRequires:  readline-devel
BuildRequires:  utfcpp-devel
BuildRequires:  wget
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5WebEngine)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(eigen3) >= 2.91.0
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(jsoncpp) >= 0.7.0
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(liblz4) >= 1.7.3
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpqxx)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(protobuf) >= 2.6.0
%if %{with pugixml}
BuildRequires:  pkgconfig(pugixml)
%endif
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(zlib)
Recommends:     %{name}-plugins
Requires:       gnuplot
Requires:       graphviz
Requires(post): /sbin/ldconfig
Requires(postun): /sbin/ldconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ParaView is a data analysis and visualization application for
visualizing large data sets.

ParaView runs on distributed and shared memory systems alike. It uses VTK
(the Visualization Toolkit) as the data processing and rendering engine.
Data exploration can be done interactively in 3D or programmatically using
batch processing.

NOTE: The version in this package has NOT been compiled with MPI support.

%package -n %{shlib}
Summary:        Shared libraries for Paraview
Group:          Productivity/Scientific/Physics

%description -n %{shlib}
This package provides the shared libraries for paraview.

%package        devel
Summary:        Headers for building ParaView plugins or embedding Catalyst
Group:          Development/Libraries/Other
Requires:       %{shlib} = %{version}
Requires:       cmake >= 3.3
Requires:       glibc-devel
Requires:       libboost_thread-devel

%description    devel
This package contains headers and libraries required to build plugins
for ParaView or to embed ParaView Catalyst in a simulation program.

%package -n python3-paraview
Summary:        Python bindings for Paraview
Group:          Productivity/Scientific/Physics
Requires:       python3
Requires:       python3-Twisted
Requires:       python3-matplotlib
Requires:       python3-numpy
Requires:       python3-qt5

%package devel-static
Summary:        Static libraries for Paraview, needed to building plugins
Group:          Productivity/Scientific/Physics
Requires:       %{name}-devel = %{version}

%description devel-static
This package contains the static libraries for Paraview, needed, for
example, to build plugins for paraview.

%description -n python3-paraview
This package provides the python(3) bindings and modules for paraview.

%package plugins
Summary:        Plugins for paraview
Group:          Productivity/Scientific/Physics
Requires:       %{name} = %{version}

%description plugins
This package provides the paraview plugins bundled with the upstream release.

%prep
%autosetup -p1 -n ParaView-v%{version}

# FIX env BASED HASHBANG
sed -Ei "1{s|#!/usr/bin/env python3|#!/usr/bin/python3|}" Clients/CommandLineExecutables/paraview-config

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects

%cmake -DCMAKE_INSTALL_LIBDIR=%{_lib} \
       -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
       -DPARAVIEW_BUILD_SHARED_LIBS:BOOL=ON \
       -DCMAKE_SKIP_RPATH:BOOL=OFF \
       -DPARAVIEW_USE_VTKM:BOOL=OFF \
       -DPARAVIEW_USE_QT:BOOL=ON \
       -DPARAVIEW_USE_PYTHON:BOOL=ON \
       -DPARAVIEW_PYTHON_SITE_PACKAGES_SUFFIX=%{_lib}/python%{py3_ver}/site-packages/paraview \
       -DVTK_PYTHON_OPTIONAL_LINK:BOOL=OFF \
       -DPARAVIEW_ENABLE_WEB:BOOL=ON \
       -DVTK_WRAP_PYTHON:BOOL=ON \
       -DVTK_OPENGL_HAS_OSMESA:BOOL=OFF \
       -DBUILD_EXAMPLES:BOOL=OFF \
       -DBUILD_TESTING:BOOL=OFF \
       -DQtTesting_INSTALL_NO_DEVELOPMENT:BOOL=ON \
       -DVTK_BUILD_QT_DESIGNER_PLUGIN:BOOL=OFF \
       -DPARAVIEW_INSTALL_DEVELOPMENT_FILES:BOOL=ON \
       -DPARAVIEW_BUILD_WITH_EXTERNAL:BOOL=ON \
       -DVTK_MODULE_USE_EXTERNAL_VTK_gl2ps=%{?with_gl2ps:ON}%{!?with_gl2ps:OFF} \
       -DVTK_MODULE_USE_EXTERNAL_VTK_libharu=%{?with_haru:ON}%{!?with_haru:OFF} \
       -DVTK_MODULE_USE_EXTERNAL_VTK_pugixml=%{?with_pugixml:ON}%{!?with_pugixml:OFF}

%cmake_build

%install
find . \( -name \*.txt -o -name \*.xml -o -name '*.[ch]' -o -name '*.[ch][px][px]' \) -exec chmod -x "{}" +

%cmake_install

# UNNECESSARY STATIC LIBS
rm %{buildroot}%{_libdir}/%{name}-%{major_ver}/plugins/GeodesicMeasurement/libFmmMesh.a

# INSTALL DOCUMENTATION USED BY THE HELP MENU IN MAIN APP
install -Dm0644 %{S:2} %{buildroot}%{_datadir}/%{name}-%{major_ver}/doc/GettingStarted.pdf
install -Dm0644 %{S:3} %{buildroot}%{_datadir}/%{name}-%{major_ver}/doc/Guide.pdf

# REMOVE paraview-config: DOESN'T WORK WITHOUT STATIC LIBS ANYWAY
rm %{buildroot}%{_bindir}/paraview-config

%fdupes %{buildroot}/

%post -n %{shlib} -p /sbin/ldconfig

%postun -n %{shlib} -p /sbin/ldconfig

%files
%license %{_datadir}/licenses/ParaView/
%{_bindir}/*
%exclude %{_bindir}/smTest*
%exclude %{_bindir}/vtk*
%{_datadir}/%{name}-%{major_ver}/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/*.appdata.xml
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_docdir}/paraview/
%dir %{_libdir}/vtk/
%dir %{_libdir}/vtk/hierarchy
%{_libdir}/vtk/hierarchy/ParaView/

%files -n %{shlib}
%{_libdir}/*.so.*

%files plugins
%{_libdir}/%{name}-%{major_ver}/

%files devel
%{_libdir}/*.so
%{_libdir}/cmake/paraview-%{major_ver}/
%{_bindir}/smTest*
%{_bindir}/vtk*
%{_includedir}/%{name}*

%files devel-static
%{_libdir}/*.a

%files -n python3-paraview
%{python3_sitearch}/%{name}/

%changelog
* Thu May  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Drop patches no longer needed:
  * 0001-Add-libogg-to-IOMovie-target-link-libraries.patch
  * fix-loguru-missing-links.patch
  * paraview-do-not-install-missing-vtk-doxygen-dir.patch
  * paraview-link-against-python.patch: pass
    DVTK_PYTHON_OPTIONAL_LINK=OFF to cmake instead (see
    https://gitlab.kitware.com/vtk/vtk/-/issues/17881).
- Update bundled_exodusii_add_missing_libpthread.patch to version
  from upstream
  (https://gitlab.kitware.com/vtk/vtk/-/merge_requests/6865).
* Tue May  5 2020 Atri Bhattacharya <badshah400@gmail.com>
- Disable the Paraview Protobuf module for openSUSE:Leap <= 15.1,
  as the FindProtobuf module bundled with cmake < 3.13 is
  incompatible with the requirements here.
- Package static libraries as part of devel-static package; this
  is needed, for example, to build plugins against paraview. See
  https://gitlab.kitware.com/paraview/paraview/-/issues/19706#note_746038.
* Wed Apr  8 2020 Christoph G <foss@grueninger.de>
- add patch fix-3d48a287-support-new-api-cgio_read_data_type.patch
  from upstream to fix build problem for Factory
* Fri Feb 28 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update minimum disk space required in _constraints: up to 16 GB
  now required.
* Tue Feb 18 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.8.0:
  * See https://blog.kitware.com/paraview-5-8-0-release-notes/.
- Rebase paraview-desktop-entry-fix.patch for updated location of
  desktop file in source.
- Drop fix-QtGUI-missing-GLX_mesa-linking.patch: no longer
  required as linking GLX_mesa to build QtGUI is now correctly
  handled by build.
- Drop 0001-Allow-compilation-on-GLES-platforms.patch: patch no
  longer applies (since vesin 5.7.0) and commenting out patch
  leads to factory_auto declining the submission.
- Use ninja instead of make as recommended by upstream and to
  speed up build; define __builder to ninja so that cmake build
  macros use this instead of the default make.
- Pass PARAVIEW_BUILD_WITH_EXTERNAL to cmake to use system third
  party libraries by default; pass VTK_MODULE_USE_EXTERNAL_<name>
  to use specific bundled libraries conditionally (gl2ps, haru,
  pugixml).
- Use %%cmake_build instead of %%make_jobs during building.
- Replace deprecated options passed to cmake by updated ones:
  * PARAVIEW_BUILD_QT_GUI -> DPARAVIEW_USE_QT
  * PARAVIEW_ENABLE_PYTHON -> PARAVIEW_USE_PYTHON.
- Update paraview-rpmlintrc to suppress warning about a non-exec
  file that is installed to %%{_bindir} and is really necessary
  (see https://gitlab.kitware.com/paraview/paraview/issues/19706);
  the previous entry no longer applies, so drop it.
- Add absolutely necessary dependencies for paraview-devel as
  Requires.
- Install python modules to %%{python3_sitearch}/paraview rather
  than the default [%%{python3_sitearch}] by setting
  PARAVIEW_PYTHON_SITE_PACKAGES_SUFFIX when configuring cmake;
  this avoids file conflicts between python3-paraview and
  python3-vtk.
- Don't install paraview-config: it doesn't work without the
  static libs being installed.
* Fri Jan 31 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.7.0:
  See https://blog.kitware.com/paraview-5-7-0-release-notes/
- Split out new subpackages: libparaview5_7 for all the shared
  libs, paraview-plugins for bundled plugins, and python3-paraview
  for python3 bindings.
- Move shared libraries to %%{_libdir} and install them as part of
  libparaview5_7.
- Update commands passed to cmake in keeping with upstream's
  overhaul.
- Drop paraview-find-qhelpgenerator-qt5.patch: no longer needed.
- Drop  paraview-fix-file-contains-date-time.patch: GCC supports
  SOURCE_DATE_EPOCH and, as such, this fix is no longer needed.
- Switch to python3: Paraview is production ready with python3
  starting with version 5.7.0, and python2 support is slated to be
  dropped from the next major upgrade.
- Rebase patches for updated version:
  * fix-libharu-missing-m.patch.
  * bundled_exodusii_add_missing_libpthread.patch.
- New patches to fix linking problems introduced with version
  5.7.0:
  * fix-loguru-missing-links.patch: Add linking to libraries libm,
    libdl, and libpthread when building loguru.
  * fix-QtGUI-missing-GLX_mesa-linking.patch: Link to library
    libGLX_mesa when building Qt GUI support.
  * paraview-link-against-python.patch to fix linking against
    the python library.
- Patch 0001-Allow-compilation-on-GLES-platforms.patch needs
  rebase; commented out for now.
- Switch an env based hashbang with one directly calling the
  required binary (python3 in this case).
- Switch as many BuildRequires as possible to pkgconfig based
  ones.
- Update rpmlintrc file to remove no longer needed filters and
  update the leftover filter (hidden file or dir) for directory
  change.
* Fri Jan 31 2020 Atri Bhattacharya <badshah400@gmail.com>
- Drop fix-libhdf5-missing-m.patch: No longer needed.
* Thu Jan 30 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Drop unused python-zope BuildRequires
- Replace Qt5WebKit BuildRequires with Qt5WebEngine
- Unbundle several dependencies, use system libraries:
  * double-conversion
  * CGNS
  * Eigen3
  * GLEW
  * HDF5
  * JsonCPP
  * liblz4
  * netcdf
  * protobuf
  * PugiXML
  * Ogg/Theora
- Add several patches from VTK package:
  * bundled_exodusii_add_missing_libpthread.patch
  * 0001-Add-libogg-to-IOMovie-target-link-libraries.patch
  * 0001-Allow-compilation-on-GLES-platforms.patch
* Fri Sep 20 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.6.2:
  * Fixes a trackpad interaction bug on macOS.
* Fri Sep 20 2019 Atri Bhattacharya <badshah400@gmail.com>
- Pass -ffat-lto-objects for static libs.
* Fri Aug 16 2019 Mark.Olesen@esi-group.com
- Update to version 5.6.1
  https://blog.kitware.com/paraview-5-6-1-release-notes/
- using tar.xz instead of tar.gz file
* Tue Dec  4 2018 Jan Engelhardt <jengelh@inai.de>
- Trim redundancies from description.
- Add ldconfig dependency. Avoid xargs use where possible.
* Thu Nov 29 2018 Mark.Olesen@esi-group.com
- Update to version 5.6.0
  https://blog.kitware.com/paraview-5-6-0-release-notes/
- add devel package
- remove Tk build requirement and adjust description since ParaView
  hasn't used Tcl/Tk for quite a few years.
- ParaViewTutorial file not updated and not available on upstream
- drop patches already applied upstream
  * paraview-pythonqt-build-fix.patch
  * fix-hdf5-gcc8.patch
  * fix-qt-5.11-931c779.patch
  * fix-no-plugin-doc-dir.patch
- modify partially applied patches
  * paraview-find-qhelpgenerator-qt5.patch
* Tue Aug 14 2018 foss@grueninger.de
- Update to version 5.5.2
  see full changelog at
  https://blog.kitware.com/paraview-5-5-0-release-notes/
- Disable build of examples
- Don't use VTKm as it cause CMake configure problems
- drop patch paraview-default-qtstyle.patch as plastic style is
  no longer set by upstream
- drop patch Fix-ParaViewDetermineVersion.patch as a similar
  change is included upstream
- update patch paraview-fix-file-contains-date-time.patch
- add patches fix-libhdf5-missing-m.patch and
  fix-libharu-missing-m.patch to add missing libraries to
  third-party dependencies included in ParaView
- add patch fix-qt-5.11-931c779.patch to fix issue with Qt 5.11
- add patch fix-no-plugin-doc-dir.patch to remove reference to
  non-existant directory below a plug-in
- add patch fix-hdf5-gcc8.patch to fix issue with GCC 8 taken
  from upstream
* Sat Mar 31 2018 jengelh@inai.de
- Trim goals from description, only the now counts.
  Trim marketing speech from description.
* Tue Aug 22 2017 badshah400@gmail.com
- Update to version 5.4.1:
  * The black render window observed on some systems when FXAA was
    enabled or an object's opacity was less than 1 has been fixed.
  * Field output for cells with non-straight edges has been
    corrected.
  * Derivatives for quadratic triangles are now computed
    correctly.
  * A bug that occurred when generating a Catalyst script with no
    images output has been fixed.
  * A problem with writing animations as AVIs was fixed.
  * Logic in the CGNS reader was updated to correctly read all
    solution nodes for each centering type when
    FlowSolutionPointers are missing.
  * Fixed crash in CGNS reader when moving forward in time.
  * Fixed problem with long-running animations not advancing past
    a certain number of time steps.
  * Resolved issue where changing one file path in the state file
    loader "Choose File Names" dialog also changed the file paths
    of other files with the same type.
  * Addressed problem with enumerated property dependencies in
    ParaViewWeb.
  * Added ability to change the font size in the ParaView user
    interface.
  * Fixed BoxLib3D file reader.
  * State files now properly support files with relative paths.
  * Removed inappropriate scalar bar scaling when saving large
    screen shots.
  * A bug in the color mapping that in some cases incorrectly
    mapped some data values to the above-range color was fixed.
  * OSPRay can now be compiled in Cray programming environments
    and for the first time has support for Intel Skylake
    processors.
  * Added lower limit to how small the GUI font size can be.
  * Addressed issue affecting layouts when loading a state file
    from the Python console.
* Sun Jul  2 2017 badshah400@gmail.com
- Update to version 5.4.0:
  * See https://blog.kitware.com/paraview-5-4-0-release-notes/ for
    a full list of updates.
- Use the %%%%cmake macro instead of using cmake manually.
- Minor rebase of existing patches for version update.
- ExcludeArch for ix86 processors until 32 bit builds can be
  sorted out; issue reported upstream.
* Mon Mar 20 2017 foss@grueninger.de
- Update to version 5.3.0
  * VTK-m Plugin for many-core systems
  * Reader and Writer Improvements and Additions
  * Fast approximate anti-aliasing (FXAA) is now on by default
  * new StreamLinesRepresentation plugin
  * Added LagrangianParticleTracker plugin
  * Python Enhancements
  * See a summary of changes at
    https://blog.kitware.com/paraview-5-3-0-release-notes/
- drop package paraview-plugin-SciberQuestToolKit as SQTK is no longer
  part of ParaView (see commit c2bc94c2efb66c4bb525383176688ddfd430ca26)
- drop paraview-build-sciberquesttoolkit-with-opengl2.patch as SQTK is
  no longer build
- add paraview-do-not-install-missing-vtk-doxygen-dir.patch to remove
  non-existing doxygen/doc/html folder from VTK.
- modified paraview-find-qhelpgenerator-qt5.patch to adapt to partial
  inclusion of original patch to upstream
* Thu Dec  8 2016 badshah400@gmail.com
- Replicate the %%cmake macro manually, stripping out the
  problematic and unused options. In particular, this restores
  passing rpm_opt_flags to C/C++ during compilation.
- Update paraview-fix-file-contains-date-time.patch to remove
  references to __DATE__ and __TIME__ also from
  Plugins/CDIReader/cdilib.c; suppresses an rpmlint warning.
- Update %%{name}-rpmlintrc file to also suppress warnings about:
  * no-manual-page-for-binary: upstream doesn't supply manpages
    and we don't care.
  * hidden-file-or-dir: this hidden file is really used as a
    catalogue of available plugins by paraview.
* Thu Nov 24 2016 badshah400@gmail.com
- Update to version 5.2.0: See a summary of changes at:
  https://blog.kitware.com/paraview-5-2-0-release-notes/ .
- Use cmake macros (except for %%cmake) for %%build and %%install
  actions; drop the paraview_cmake_options and send the options
  directly to cmake. We do not use the %%cmake macro because
  it passes the RPM optflags to cmake, and with paraview 5.2 these
  flags cause compilation errors; see
  https://gitlab.kitware.com/paraview/paraview/issues/17049.
- Turn off system GL2PS and DIY for bundled VTK.
- Switch to using Qt5 for openSUSE > 13.2 and Leap 42.2 and
  higher (Qt5 >= 5.6.0 is required).
- Add BuildRequires on python-Sphinx, python-qt*-devel; new
  requirements.
- Add BuildRequires on pkgconfig(libpng), pkgconfig(freetype2) and
  pkgconfig(xt); these are all required and being implicitly
  pulled in by libqt4-devel.
- Add paraview-find-qhelpgenerator-qt5.patch: Help find
  qhelpgenerator-qt5 instead of qhelpgenerator when Qt5 is used.
- Add paraview-pythonqt-build-fix.patch to fix build issues with
  PythonQtPlugin; patch taken from upstream.
- Add paraview-build-sciberquesttoolkit-with-opengl2.patch to
  enable building of SciberQuestToolKit even when OpenGL2 is used
  as the default VTK rendering (needs testing).
- Drop require-only-cmake-3_0.patch, cmake >= 3.3 is now required.
- Add documentation linked to from the Help menu in main
  application as additional sources and install them where it
  looks for them (ParaViewGettingStarted-5.2.0.pdf,
  ParaViewGuide-5.2.0.pdf, ParaViewTutorial.pdf).
- Send other docs to %%{_docdir} by explicitly passing the cmake
  option VTK_INSTALL_DOC_DIR.
* Fri Jul 29 2016 foss@grueninger.de
- update to version 5.1.2
  * Rendering translucent geometries: fixed client-server configurations
    when rendering remotely and resolved issues with multiple windows/views
    were present.
  * Exodus reader: Fixed bug in Exodus reader which was causing the reader to
    improperly read files with no timesteps.
  * Fixed the “?” button to show filter documentation.
  * Add option to Ghost Cells Generator filter to specify the number of ghost
    levels to generate.
  * Cinema Fixed SpecB was not revolving the camera around the data centroid.
- adjust require-only-cmake-3_0.patch
* Tue Jun 21 2016 foss@grueninger.de
- update to version 5.1.0
  + add OSPRay ray tracing renderer
  + interpolating point clouds
  + generic arrays
  + x-ray view
  + resampling to image
  + List of changes at
    http://www.paraview.org/Bug/changelog_page.php?version_id=122
- adjust patch paraview-default-qtstyle.patch
- add require-only-cmake-3_0.patch to lower required CMake version
  to 3.0
* Wed Mar 30 2016 foss@grueninger.de
- update to version 5.0.1
  + Trace recorder fails for CTH data
  + improvements to cinema
  + Move Show Axis functionality into Edit Axes Grid
  + hover points on is deathly slow remote server
  + CGNS reader not available in non-MPI windows binaries
  + update pvospray
  + Keyboard shortcut Alt+A is assigned twice
  + Rubber band selection is broken
  + List of changes at
    http://www.paraview.org/Bug/changelog_page.php?version_id=126
* Tue Mar 15 2016 dvaleev@suse.com
- Add disk constraint 8GB
* Mon Jan 11 2016 foss@grueninger.de
- Update to version 5.0.0
  + New Rendering Engine
  + OpenSWR and Mesa support
  + Include OSPray
  + Off-screen rendering with EGL
  + Community Atmosphere Model (Cam5) Catalyst Adaptor
  + Accelerated Algorithms plug-in
  + List of changes at
    http://www.paraview.org/Bug/changelog_page.php?version_id=121
* Mon Sep 14 2015 badshah400@gmail.com
- Update to version 4.4.0:
  + List of changes at
    http://www.paraview.org/Bug/changelog_page.php?version_id=114.
- Drop paraview-freetype-2.5.4.patch: incorporated upstream.
* Sat Feb 14 2015 foss@grueninger.de
- Update to version 4.3.1:
  + See list of changes at
    http://www.paraview.org/Bug/changelog_page.php
- Packaging changes:
  + Install new file /usr/share/cmake/hdf5/libhdf5.settings
* Mon Jan  5 2015 dimstar@opensuse.org
- Add paraview-freetype-2.5.4.patch: Fix build with FreeType 2.5.4
  API changes.
* Wed Oct  1 2014 foss@grueninger.de
- Update to version 4.2.0:
  + See list of changes at
    http://vtk.org/Bug/changelog_page.php?version_id=108
- Packaging changes:
  + Drop paraview-Mesa10.3-build-failures.patch as this patch has
    been included upstream
* Mon Sep  8 2014 badshah400@gmail.com
- Update to version 4.2.0-RC1:
  + See list of changes at
    http://vtk.org/Bug/changelog_page.php?version_id=108
- Packaging changes:
  + Add paraview-desktop-entry-fix.patch to fix paraview's desktop
    menu entry by properly inserting required key-value pairs
  + Drop paraview-SciberQuestToolKit-install-path.patch; no longer
    needed as properly implemented upstream
  + Rebase carried-over patches to apply cleanly against present
    version
  + Add paraview-Mesa10.3-build-failures.patch to workaround
    build failures when compiling against Mesa >= 10.3; patch
    taken from upstream git and rebased; applied only for
    openSUSE >= 13.2
  + Specfile changes:
  - Prepare for gcc 4.9.0 by working around a compiler
    issue
  - Package .desktop entry and icon files; post(un) scriptlets
    for updating hicolor icon theme and updating desktop menu
    are used
  - Package appdata file
  - Fix python-bytecode-inconsistent-mtime rpmlint warnings by
    recompiling all relevant .py files.
* Tue Feb  4 2014 badshah400@gmail.com
- Build with system zope (python-zope.interface) and twisted
  (python-twisted); introduces BuildRequires and Requires on the
  two packages
- Remove unnecessary Requires on python-matplotlib.
* Sun Feb  2 2014 badshah400@gmail.com
- Update to version 4.1.0:
  + See list of changes at
    http://vtk.org/Bug/changelog_page.php?version_id=102
- Packaging changes:
  + Use full URL for source tarball
  + Drop patches:
  - paraview-fix-vtkpython-modules-install-dir.patch: corrected
    upstream
  - paraview-no-return-in-nonvoid-function.patch: corrected
    upstream
  + Rebase existing patches
  + Also fix a new occurrance of __DATE__ in a source file
    within paraview-fix-file-contains-date-time.patch
  + Change build type to RelWithDebInfo from Release
    (DCMAKE_BUILD_TYPE=RelWithDebInfo).
* Mon Jul  8 2013 badshah400@gmail.com
- Update to version 4.0.1:
  + Undocumented upstream changes
- Changes from version 4.0:
  + Too many to list, see
    http://paraview.org/Bug/changelog_page.php?version_id=52
    for a complete list
- Drop paraview-fix-build-with-system-jpeg.patch; implemented
  upstream
- Use matplotlib during building to enable MathText rendering;
  introduces build time and runtime requirement on
  python-matplotlib
- Add patches:
  + paraview-fix-vtkpython-modules-install-dir.patch: Workaround
    vtk's python modules getting installed in the wrong location;
    upstream bug report at
    http://paraview.org/Bug/view.php?id=14168
  + paraview-fix-file-contains-date-time.patch: Remove reference
    to __DATE__ and __TIME__ from source files
- Use fdupes to link duplicated files.
* Thu Jun 20 2013 badshah400@gmail.com
- Enable python scripting with paraview
  (cmake variable DPARAVIEW_ENABLE_PYTHON:BOOL=ON); had been
  turned off because earlier versions of paraview had some
  building issues with this enabled.
* Tue Mar 12 2013 badshah400@gmail.com
- Update to version 3.98.1:
  + See full list of changes at
    http://paraview.org/Bug/changelog_page.php?version_id=99.
- Add paraview-fix-build-with-system-jpeg.patch to fix build
  errors when compiled with recent jpeg headers (libjpeg8-devel >=
  8.0)
- Use smp flags for make to speed up build.
* Wed Feb 27 2013 badshah400@gmail.com
- License of SciberQuestToolKit subpackage is: GPL-2.0+ or
  LGPL-3.0+.
* Mon Feb 25 2013 badshah400@gmail.com
- Split the SciberQuestToolKit plugin into its own package,
  license it as GPL-3.0+ or LGPL-3.0+ (bnc#804987)
- The minimum version of libqt4-devel required for compiling is
  4.7.0; correct BuildRequires accordingly.
* Tue Jan 15 2013 badshah400@gmail.com
- Remove paraview-gcc47.patch; patch incorporated upstream.
* Tue Jan  8 2013 badshah400@gmail.com
- Update to version 3.98.0:
  + Too many changes to list, see
    http://paraview.org/Bug/changelog_page.php?version_id=97
  + Fixes licensing issues (bnc#763208)
- Remove paraview-boost-1.49-compat.patch, incorporated upstream
- Add paraview-no-return-in-nonvoid-function.patch to fix non-void
  function returning nothing
- Add paraview-SciberQuestToolKit-install-path.patch to fix
  install path of SciberQuestToolKit plugin
- Turn off OSMESA bindings because these are no longer
  recommended.
* Fri Oct 26 2012 badshah400@gmail.com
- Update to version 3.14.1:
  + Bug fix release, see a complete list at
    http://paraview.org/Bug/changelog_page.php?version_id=95 .
* Sat May 12 2012 scorot@free.fr
- fix SLE and 11.3 build with BuildRequires qt4-assistant-adp-devel
  for 11.4 and higher
* Sat Apr 28 2012 badshah400@gmail.com
- Added paraview-gcc47.patch to fix build failures with gcc >= 4.7:
  this fixes building on openSUSE > 12.1.
* Sun Apr  8 2012 badshah400@gmail.com
- Update to version 3.14.0:
  + Too many changes to list. See complete list at
    http://www.paraview.org/Bug/changelog_page.php?version_id=94
- Added paraview-boost-1.49-compat.patch to workaround vtk's
  incompatibility with boost version 1.48 and higher; fixes build
  on factory.
* Sun Nov  6 2011 badshah400@gmail.com
- Update to version 3.12.0:
  + Too many changes to list. See complete list at
    http://www.paraview.org/Bug/changelog_page.php?version_id=85
- Removed paraview-demo-patch. Changes committed upstream.
- Removed paraview-sqldatabaseschema.patch. Build failure
  properly taken care of upstream.
* Sun Apr  3 2011 badshah400@gmail.com
- Added paraview-default-qtstyle.patch to make paraview inherit
  user-set qt-GUI style instead of always using Plastique
* Sat Apr  2 2011 badshah400@gmail.com
- Added rpmlintrc file to suppress devel-file warnings for
  required files
* Thu Mar 31 2011 badshah400@gmail.com
- Initial package (version 3.10.0)
